package org.twinone.ejempljson;

import java.io.InputStream;

import org.twinone.ejemplojson.R;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.AsyncTask;
import android.text.Html;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.ImageView.ScaleType;
import android.widget.TextView;

public class AmigosAdapter extends BaseAdapter {

	private Amigo[] mAmigos;
	private LayoutInflater mInflater;

	public AmigosAdapter(Context context, Amigo[] items) {
		mAmigos = items;
		mInflater = (LayoutInflater) context
				.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
	}

	@Override
	public int getCount() {
		return mAmigos.length;
	}

	@Override
	public Object getItem(int position) {
		return mAmigos[position];
	}

	@Override
	public long getItemId(int position) {
		return position + 1;
	}

	@Override
	public View getView(int i, View convertView, ViewGroup parent) {
		return createViewFromResource(i, convertView, parent,
				R.layout.listview_item);
	}

	public View createViewFromResource(int position, View convertView,
			ViewGroup parent, int resource) {

		View view = convertView;
		Amigo amigo = mAmigos[position];

		if (amigo != null) {
			view = mInflater.inflate(resource, parent, false);

			// Los TextViews que representan cada dato sobre el amigo en
			// cuestion
			TextView tvNombre = (TextView) view.findViewById(R.id.tvNombre);
			TextView tvEdad = (TextView) view.findViewById(R.id.tvEdad);
			TextView tvDescripcion = (TextView) view
					.findViewById(R.id.tvDescripcion);
			ImageView ivImagen = (ImageView) view.findViewById(R.id.ivImagen);

			// Todos tienen nombre y edad, (espero)
			tvNombre.setText(amigo.Nombre);
			tvEdad.setText(String.valueOf("(" + amigo.Edad + ")"));

			// Construimos la descripcion del amigo:
			StringBuilder desc = new StringBuilder();

			desc.append("<i><b>" + amigo.Nombre + "</b>");
			desc.append(" es <b>");
			if (amigo.Trabajo != null && amigo.Trabajo.length() > 0) {
				desc.append(amigo.Trabajo);
			} else {
				desc.append("parado");
			}
			desc.append("</b>. Tiene <b>" + amigo.Edad + "</b> años,");

			if (amigo.Deporte != null && amigo.Deporte.length() > 0) {
				desc.append(" su deporte favorito es <b>" + amigo.Deporte
						+ "</b>");
			} else {
				desc.append(" no le gusta <b>ningún deporte</b>");
			}

			desc.append(" y está <b>" + (amigo.Casado ? "casado" : "soltero")
					+ "</b>");
			desc.append(".</i>");

			String descripcion = desc.toString();

			tvDescripcion.setText(Html.fromHtml(descripcion));

			// Y por ultimo, su foto
			if (amigo.Imagen != null) {
				Log.d("", "Getting image url: " + amigo.Imagen);
				new DownloadImageTask(ivImagen).execute(amigo.Imagen);
			} else {
				ivImagen.setVisibility(View.GONE);
			}

		}
		return view;

	}

	// Downloads an image and sets it to an ImageView
	private class DownloadImageTask extends AsyncTask<String, Void, Bitmap> {
		ImageView view;

		public DownloadImageTask(ImageView bmImage) {
			this.view = bmImage;
		}

		protected Bitmap doInBackground(String... urls) {
			String urldisplay = urls[0];
			Bitmap icon = null;
			try {
				InputStream in = new java.net.URL(urldisplay).openStream();
				icon = BitmapFactory.decodeStream(in);
			} catch (Exception e) {
			}
			return icon;
		}

		protected void onPostExecute(Bitmap result) {
			view.setImageBitmap(result);
			view.setScaleType(ScaleType.CENTER_CROP);
		}
	}

}
