package org.twinone.ejempljson.json;

import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;

import org.twinone.ejempljson.Amigo;
import org.twinone.ejempljson.AmigosAdapter;
import org.twinone.ejemplojson.R;

import android.app.Activity;
import android.os.AsyncTask;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ListView;
import android.widget.Toast;

import com.google.gson.Gson;

public class AmigosActivity extends Activity implements OnClickListener {

	private int MODE_LOCAL = 0;
	private int MODE_SERVER = 1;

	private int mMode = MODE_LOCAL;

	private ListView mListView;

	private AmigosAdapter mAdapter;

	private Button mBLocal;
	private Button mBServer;

	private static final String URL = "http://twinone.org/androidparty/amigos.php";

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setTitle("Mis amigos");
		setContentView(R.layout.amigos_activity);

		mListView = (ListView) findViewById(R.id.listview);
		mBLocal = (Button) findViewById(R.id.blocal);
		mBServer = (Button) findViewById(R.id.bserver);

		mBLocal.setOnClickListener(this);
		mBServer.setOnClickListener(this);

		actualizar();
	}

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.blocal:
			mMode = MODE_LOCAL;
			actualizar();
			break;
		case R.id.bserver:
			mMode = MODE_SERVER;
			actualizar();
			break;

		}
	}

	private void actualizar() {
		if (mMode == MODE_LOCAL) {
			cargarDatos(leerAssets());
		} else {
			new GetItemsAsyncTask().execute(URL);
		}
	}

	private String leerAssets() {
		try {
			StringBuilder buf = new StringBuilder();
			InputStream json = getAssets().open("amigos.json");
			BufferedReader in = new BufferedReader(new InputStreamReader(json,
					"UTF-8"));
			String str;

			while ((str = in.readLine()) != null) {
				buf.append(str);
			}
			in.close();
			return buf.toString();
		} catch (Exception e) {
			return null;
		}
	}

	private void cargarDatos(String datos) {

		Gson gson = new Gson();
		Amigo[] amigos = null;

		amigos = (Amigo[]) gson.fromJson(datos, Amigo[].class);

		if (amigos == null) {
			Toast.makeText(this, "Error al descargar", Toast.LENGTH_SHORT)
					.show();
			return;
		}

		// Meter los datos en el ListView
		mAdapter = new AmigosAdapter(this, amigos);
		mListView.setAdapter(mAdapter);

	}

	/*
	 * AsyncTask that gets the contents of an url as a String in the background
	 */
	private class GetItemsAsyncTask extends AsyncTask<String, Void, String> {

		@Override
		protected String doInBackground(String... params) {
			return getItemsString(params[0]);
		}

		@Override
		protected void onPostExecute(String result) {
			cargarDatos(result);
			super.onPostExecute(result);
		}

	}

	public String getItemsString(String link) {
		try {
			URL url = new URL(link);
			HttpURLConnection urlConnection = (HttpURLConnection) url
					.openConnection();

			InputStream in = new BufferedInputStream(
					urlConnection.getInputStream());
			BufferedReader br = new BufferedReader(new InputStreamReader(in));
			StringBuilder data = new StringBuilder();
			String tmp;
			while ((tmp = br.readLine()) != null) {
				data.append(tmp);
			}
			urlConnection.disconnect();
			return data.toString();
		} catch (Exception e) {
			return null;
		}
	}

}
