package org.twinone.ejempljson.sqlite;

import java.util.List;
import java.util.Random;

import org.twinone.ejempljson.Amigo;
import org.twinone.ejempljson.AmigosAdapter;
import org.twinone.ejemplojson.R;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.Toast;

public class SQLiteActivity extends Activity implements OnClickListener {

	private static final int NUMBER_OF_IMAGES = 15;

	private Button mBInsertar;
	private Button mBBorrar;
	private Button mBEliminarBD;
	private Button mBConsulta;

	private ListView mListView;

	private AyudanteBD mAyudante;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.db_activity);

		// Creamos el ayudante
		mAyudante = new AyudanteBD(this);

		mBInsertar = (Button) findViewById(R.id.binsertar);
		mBBorrar = (Button) findViewById(R.id.bborrar);
		mBEliminarBD = (Button) findViewById(R.id.beliminarbd);
		mBConsulta = (Button) findViewById(R.id.bconsulta);

		mBInsertar.setOnClickListener(this);
		mBBorrar.setOnClickListener(this);
		mBEliminarBD.setOnClickListener(this);
		mBConsulta.setOnClickListener(this);

		mListView = (ListView) findViewById(R.id.listview);

		// Mostrar los datos por primera vez
		actualizar();
	}

	// Muestra los datos en el ListView
	private void actualizar() {
		AyudanteBD h = new AyudanteBD(this);
		List<Amigo> amigos = h.seleccionarTodosLosAmigos();

		// Convertimos la lista a un array:
		Amigo[] array = new Amigo[amigos.size()];
		amigos.toArray(array);

		// Metemos los amigos en el listview
		AmigosAdapter adapter = new AmigosAdapter(this, array);
		mListView.setAdapter(adapter);

	}

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		case R.id.bborrar:
			mostrarDialogoBorrarAmigo();
			break;
		case R.id.beliminarbd:
			mostrarDialogoEliminarBD();
			break;
		case R.id.binsertar:
			mostrarDialogoInsertar();
			break;
		case R.id.bconsulta:
			mostrarDialogoConsulta();
			break;
		}
	}

	private void mostrarDialogoConsulta() {
		AlertDialog.Builder ab = new AlertDialog.Builder(this);
		ab.setTitle("Consulta SQL");
		final EditText et = new EditText(this);
		ab.setMessage("Introduce la consulta");
		ab.setView(et);
		ab.setPositiveButton(android.R.string.ok,
				new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface arg0, int arg1) {
						String sql = et.getText().toString();
						boolean correcto = mAyudante.ejecutarSQL(sql);

						if (!correcto) {
							Toast.makeText(SQLiteActivity.this,
									"Consulta incorrecta :(",
									Toast.LENGTH_SHORT).show();
						}

						actualizar();
					}
				});
		ab.setNegativeButton(android.R.string.cancel, null);
		ab.show();

	}

	private void mostrarDialogoBorrarAmigo() {
		AlertDialog.Builder ab = new AlertDialog.Builder(this);
		ab.setTitle("Borrar amigo");
		final EditText et = new EditText(this);
		ab.setMessage("Introduce el nombre del amigo a borrar");
		ab.setView(et);
		ab.setPositiveButton(android.R.string.ok,
				new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface arg0, int arg1) {
						String nombre = et.getText().toString();
						mAyudante.borrarAmigo(nombre);

						actualizar();

					}
				});
		ab.setNegativeButton(android.R.string.cancel, null);
		ab.show();
	}

	private void mostrarDialogoEliminarBD() {
		AlertDialog.Builder ab = new AlertDialog.Builder(this);
		ab.setTitle("Borrar BD");
		ab.setMessage("Esto borrará toda la base de datos... ¿Seguro que quieres continuar?");
		ab.setPositiveButton(android.R.string.ok,
				new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface arg0, int arg1) {
						mAyudante.borrarTodosLosAmigos();

						actualizar();

					}
				});
		ab.setNegativeButton(android.R.string.cancel, null);
		ab.show();
	}

	private void mostrarDialogoInsertar() {
		AlertDialog.Builder ab = new AlertDialog.Builder(this);
		ab.setTitle("Insertar amigo");

		LayoutInflater inflater = LayoutInflater.from(this);
		ViewGroup v = (ViewGroup) inflater.inflate(
				R.layout.dialogo_insertar_amigo, null);

		final EditText nombre = (EditText) v.findViewById(R.id.insertar_nombre);
		final EditText edad = (EditText) v.findViewById(R.id.insertar_edad);
		final EditText trabajo = (EditText) v
				.findViewById(R.id.insertar_trabajo);
		final EditText deporte = (EditText) v
				.findViewById(R.id.insertar_deporte);
		final CheckBox casado = (CheckBox) v.findViewById(R.id.insertar_casado);

		ab.setMessage("Añadir amigo");
		ab.setView(v);

		ab.setPositiveButton(android.R.string.ok,
				new DialogInterface.OnClickListener() {

					@Override
					public void onClick(DialogInterface arg0, int arg1) {
						Amigo amigo = new Amigo();
						amigo.Nombre = nombre.getText().toString();
						amigo.Deporte = deporte.getText().toString();
						amigo.Trabajo = trabajo.getText().toString();
						amigo.Casado = casado.isChecked();

						// Añadimos una imagen aleatoria...
						int rand = new Random().nextInt(NUMBER_OF_IMAGES);
						amigo.Imagen = "http://twinone.org/androidparty/img/"
								+ rand + ".jpg";

						// Asegurarnos de que todos tienen nombre...
						if (amigo.Nombre.length() == 0) {
							amigo.Nombre = "Un desconocido";
						}

						String edadString = edad.getText().toString();
						try {
							amigo.Edad = Integer.valueOf(edadString);
						} catch (Exception e) {
							// Numero incorrecto.
						}

						long id = mAyudante.insertarAmigo(amigo);

						Toast.makeText(SQLiteActivity.this,
								"Insertado el amigo con ID: " + id,
								Toast.LENGTH_SHORT).show();

						actualizar();

					}
				});
		ab.setNegativeButton(android.R.string.cancel, null);
		ab.show();
	}

}
